@@ -23,7 +23,6 @@ import (
 	"git.zabbix.com/ap/mongodb/plugin/handlers"
 	"git.zabbix.com/ap/plugin-support/metric"
 	"git.zabbix.com/ap/plugin-support/plugin"
-	"git.zabbix.com/ap/plugin-support/tlsconfig"
 	"git.zabbix.com/ap/plugin-support/uri"
 	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
@@ -33,6 +32,8 @@ const (
 	hkInterval = 10
 )
 
+var Impl Plugin
+
 // Plugin -
 type Plugin struct {
 	plugin.Base
@@ -40,8 +41,6 @@ type Plugin struct {
 	options PluginOptions
 }
 
-var Impl Plugin
-
 func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvider) (result interface{}, err error) {
 	params, _, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
@@ -58,18 +57,12 @@ func (p *Plugin) Export(key string, rawParams []string, ctx plugin.ContextProvid
 		return nil, err
 	}
 
-	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
-		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
-	if err != nil {
-		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
-	}
-
 	handleMetric := getHandlerFunc(key)
 	if handleMetric == nil {
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri, details)
+	conn, err := p.connMgr.GetConnection(*uri, params)
 	if err != nil {
 		// Special logic of processing connection errors should be used if mongodb.ping is requested
 		// because it must return pingFailed if any error occurred.
@@ -101,6 +94,7 @@ func (p *Plugin) Start() {
 		time.Duration(p.options.KeepAlive)*time.Second,
 		time.Duration(p.options.Timeout)*time.Second,
 		hkInterval*time.Second,
+		p.Logger,
 	)
 }
 
